@@ -1,6 +1,8 @@
 # Toolchain icestorm class
 
 import requests
+requests.packages.urllib3.disable_warnings()
+
 from os import rename
 from os.path import isdir, join
 
@@ -14,7 +16,10 @@ class IcestormInstaller(Installer):
         self.name = 'toolchain-icestorm'
         self.platform = self._get_platform()
         self.version = self._get_version()
-        self.extension = 'tar.gz'
+        if 'windows' in self.platform:
+            self.extension = 'zip'
+        else:
+            self.extension = 'tar.gz'
 
     def install(self):
         super(IcestormInstaller, self).install()
@@ -27,7 +32,7 @@ class IcestormInstaller(Installer):
 
     def _get_download_url(self):
         url = '{0}/0.{1}/{2}'.format(
-            'https://github.com/bqlabs/toolchain-icestorm/releases/download',
+            'https://github.com/FPGAwars/toolchain-icestorm/releases/download',
             self.version,
             self._get_package_name())
         return url
@@ -41,7 +46,7 @@ class IcestormInstaller(Installer):
         return name
 
     def _get_version(self):
-        releases_url = 'https://api.github.com/repos/bqlabs/toolchain-icestorm/releases/latest'
+        releases_url = 'https://api.github.com/repos/FPGAwars/toolchain-icestorm/releases/latest'
         response = requests.get(releases_url)
         releases = response.json()
         version = releases['tag_name'].split('.')[1]  # 0.X -> X
